@@ -1,9 +1,8 @@
-from django.db.models import CharField, BooleanField, ForeignKey, CASCADE
+from django.db.models import CharField, BooleanField, ForeignKey, CASCADE, OneToOneField, SET_NULL
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
 from ocp_project_plugin.choices import AppEnvironmentClusterEnvChoices, AppEnvironmentDeploymentKindChoices
-from ocp_project_plugin.fields import MemoryResourceField
 from ocp_project_plugin.models import OCPProject
 from ocp_project_plugin.utils.gitlab import clone_repo
 
@@ -46,6 +45,7 @@ class AppEnvironment(NetBoxModel):
         help_text="The git Branch of the Repository e.g. main"
     )
     access_token = CharField(
+        blank=True,
         max_length=100,
         verbose_name="Git Access Token",
         help_text="The access token of the tst git repo, int & prd are automatically provided"
@@ -55,8 +55,13 @@ class AppEnvironment(NetBoxModel):
         verbose_name="Git Path",
         help_text="Path of the deployment files e.g. overlays/tst"
     )
-    egress_ip = CharField(
-        max_length=20,
+    egress_ip = OneToOneField(
+        to='ipam.IPAddress',
+        on_delete=SET_NULL,
+        related_name='app_env_egress_ip',
+        blank=True,
+        null=True,
+        verbose_name='Egress IP'
     )
     monitoring = BooleanField(
         default=True,
@@ -74,11 +79,11 @@ class AppEnvironment(NetBoxModel):
         verbose_name="CPU request",
         help_text="The CPU request value e.g. 1",
     )
-    requests_memory = MemoryResourceField(
-        #max_length=5,
+    requests_memory = CharField(
+        max_length=5,
         blank=True,
         verbose_name="Memory request",
-        help_text="The memory value e.g. 200Mi",
+        help_text="The memory value e.g. 200Mi or 1Gi",
     )
     limits_cpu = CharField(
         max_length=5,
@@ -86,11 +91,11 @@ class AppEnvironment(NetBoxModel):
         verbose_name="CPU Limit",
         help_text="The CPU request value e.g. 2",
     )
-    limits_memory = MemoryResourceField(
-        #max_length=5,
+    limits_memory = CharField(
+        max_length=5,
         blank=True,
         verbose_name="Memory Limit",
-        help_text="The CPU memory value e.g. 400Mi",
+        help_text="The CPU memory value e.g. 400Mi or 2Gi",
     )
     ocp_project = ForeignKey(OCPProject, on_delete=CASCADE, related_name="app_env_ocp_project")
 
@@ -113,6 +118,9 @@ class AppEnvironment(NetBoxModel):
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/AppEnvironment/'
 
-    def save(self, *args, **kwargs):
-        clone_repo()
-        super(AppEnvironment, self).save(*args, **kwargs)
+    #def save(self, *args, **kwargs):
+    #    clone_repo()
+    #    super(AppEnvironment, self).save(*args, **kwargs)
+
+    def get_cluster_color(self):
+        return AppEnvironmentClusterEnvChoices.colors.get(self.cluster_env)
