@@ -21,7 +21,7 @@ from ocp_project_plugin.views import (
     OCPProjectBulkEditView,
     OCPProjectBulkDeleteView,
 )
-from ocp_project_plugin.views.worker import add_project, clone_repo
+from ocp_project_plugin.views.worker import add_project, clone_repo, sync_project
 
 app_name = "ocp_project_plugin"
 
@@ -65,4 +65,5 @@ urlpatterns = [
     #
     path("worker/clone_repo", clone_repo, name="clone_repo"),
     path("worker/add_project", add_project, name="add_project"),
+    path("worker/sync/", sync_project, name="sync_project"),
 ]
