@@ -31,6 +31,13 @@ def clone_repo(request):
         return redirect(reverse('plugins:ocp_project_plugin:ocpproject_list'))
 
 
+def sync_project(request):
+    logger = logging.getLogger('netbox.ocp_project_plugin')
 
+    logger.warning(f'{request}')
+    logger.warning(f'{request.ocp_project}')
+
+    get_queue("default").enqueue("ocp_project_plugin.worker.pull_repository")
+    return redirect(reverse('plugins:ocp_project_plugin:ocpproject_list'))
 
 
